@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+
 """
 Creates an `MA-plot` to compare transcription levels of a set of genes
 (or other features) in two different conditions, from a CSV file.
@@ -7,7 +8,8 @@ will be plotted in a different color, and be annotated if requested.
 
 The class AnnoteFinder is used to create interactive - clickable - plots.
 """
-__version__ = '1.0.0'
+
+__version__ = '1.0.1'
 
 import sys, os, json, urllib, math, csv, optparse, random, string
 import numpy
@@ -373,11 +375,11 @@ maplot.py [-h] [-c --cols] [-l --labels] [-m --mode] [-f --format] [-s --sep]
            samples to compare, and one with labels for each pair of points. Files must all
            be in the same format. By default numeric columns are 2 and 3,
            whilst column 1 contains the labels. Else, precise which columns to use with the
-           `--cols` argument.
+           `--cols` and `--labels` arguments.
 
 **Output**: depending on the chosen `--mode`, prints to stdout the name of the .png file produced,
-            prints to stdout a json containing enough information to reconstruct the plot using
-            Javascript, or produces an interactive matplotlib figure. """
+            produces an interactive matplotlib figure, or prints to stdout a json to reconstruct
+            the plot in a Javascript canvas. """
 
 help = iter([
 """The numbers or names of the two columns containing the numeric data to compare, separated by
@@ -440,6 +442,7 @@ def main():
 
         (opt, args) = parser.parse_args()
         args = [os.path.abspath(a) for a in args]
+        if len(args) < 1: parser.error('No data file provided.')
 
         annotate = None
         if opt.annotate:
